#include <ESP8266WiFi.h>
#include <ESP8266WebServer.h>
#include "LittleFS.h"

const char *ssid = "ESP8266_sw";
const char *password = "12345678";
IPAddress ap_ip(192, 168, 4, 10);           // IP Address
IPAddress ap_gateway(192,168, 4, 0);         // Gateway Address

const char *SSID = "xxxxxxxxxx";
const char *PASSWORD = "yyyyyyyyyy";
IPAddress ip(192, 168, 3, 220);           // IP Address
IPAddress gateway(192,168, 3, 1);         // Gateway Address
IPAddress subnet(255, 255, 255, 0);       // Subnet Address

ESP8266WebServer server(80);

#define   P_Mode      4
#define   Run_LED     12
#define   Ready_LED   13
#define   ON_OFF      14
 
String index_top =
  "<!DOCTYPE html>\n<html>\n<head>\n<meta charset='utf-8'>\n"
  "<meta name='viewport' content='width=device-width,initial-scale=1'>\n"
  "<link rel='stylesheet' type='text/css' href='switch.css'>\n"
  "<title>Switch 1.0</title>\n</head>\n<body>\n<center>\n<div class='b_frame'>\n"
  "<div class='t_font'><u>Switch 1.0</u></div><br>\n"
  "<form method='get'>\n<button type='submit' name='1' value='0' style='background: #";

String index_bottom =
  "</button>\n</form>\n</div>\n</center>\n<script>\nhistory.pushState(null,null,'/');\n</script>\n</body>\n</html>\n";

int switch_flg = 0;

void setup()
{
    pinMode(Run_LED,OUTPUT);
    pinMode(Ready_LED,OUTPUT);
    pinMode(ON_OFF,OUTPUT);
    pinMode(P_Mode,INPUT);
    digitalWrite(Run_LED, LOW);
    digitalWrite(Ready_LED, LOW);
    digitalWrite(ON_OFF, LOW);

    Serial.begin(115200);
    Serial.println();

    LittleFS.begin();
    Serial.println("LittleFS started");
    
    Serial.println("Connecting to WiFi");
    WiFi.disconnect(true);
    WiFi.softAPdisconnect(true);
    delay(500);

    if(digitalRead(P_Mode))
    {
      WiFi.mode(WIFI_STA);
      WiFi.config(ip, gateway, subnet);
      WiFi.begin(SSID, PASSWORD);
      delay(1000);

      // Try forever
      while (WiFi.status() != WL_CONNECTED) 
      {
        Serial.println("...Connecting to WiFi");
        delay(1000);
      }
      Serial.println("Connected");
      Serial.println(SSID);
      Serial.print("IP address: ");
      Serial.println(WiFi.localIP());
    }
    else
    {
      WiFi.softAPConfig(ap_ip, ap_gateway, subnet);
      WiFi.softAP(ssid, password);
      IPAddress myIP = WiFi.softAPIP();
      Serial.print("AP IP address: ");
      Serial.println(myIP);
    }

    server.begin();
    server.on("/", handleRoot);
    server.onNotFound(handleWebRequests); 
    Serial.println("HTTP server started");
    digitalWrite(Ready_LED, HIGH);
}

void loop()
{
  server.handleClient();
}

void handleRoot()
{
  String cmd;

  cmd=server.argName(0);
  switch(cmd.toInt())
  {
    case 1:   // swithc On or Off
            switch_flg = !switch_flg;
            digitalWrite(Run_LED, switch_flg);
            digitalWrite(ON_OFF, switch_flg);
            break;
  }

  cmd = index_top;
  if(switch_flg) cmd += "fc2222'>On";
  else cmd += "228b22'>Off";
  cmd += index_bottom;
  server.send(200, "text/html", cmd);
}

void handleWebRequests()
{
  String dataType = "text/plain";
  String path;
  File dataFile;

  path = server.uri();
  if(path.endsWith(".css")) dataType = "text/css";
  else if(path.endsWith(".js")) dataType = "application/javascript";
  delay(5);

  dataFile = LittleFS.open(path.c_str(), "r");
  server.streamFile(dataFile, dataType);
  dataFile.close();
}
